package com.azt.itower.deck;

import java.awt.Point;
import com.azt.itower.game.GameException;
import com.azt.itower.game.CardModel;
import com.azt.itower.command.*;

/**
 *
 * A Factory Class that adheres to the AbstractDeckFactory rules and provides
 * all the cards of the grey deck
 * @author thanassis@thanassis.com
 * @version 0.9 beta
 */
public class GrayDeckFactory extends AbstractDeckFactory {

    /**
     * Inititalised The GreyDeckFactory
     * @exception GameException
     */
    public void init() throws GameException {
        init(kGRAY_DECK_IMG, CardModel.kSTONES);
    }

    /**
     * Creates a model for a card belonging to particular point (row, column)
     * of that deck. The massive switch statement is responsible for creating
     * each card of the gray deck.
     * @param Point The point that defines the column and row of the card
     * @return CardModel The CardModel that every Card needs to get state and behaviour
     */
    protected CardModel createCardModel(Point p) {
        CardModel model = null;
        switch (p.y) {
            case 0:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Castle Works", 2, getCardModelType(), " Build +5 Wall ",
                            new ChangeAttributeCommand("Wall", 5, ChangeAttributeCommand.CURRENT));
                        break;
                    case 1:
                        model = new CardModel("Shrine", 5, getCardModelType(), " Build +6 Wall ",
                            new ChangeAttributeCommand("Wall", 6, ChangeAttributeCommand.CURRENT));
                        break;
                    case 2:
                        model = new CardModel("Pray to Gods", 2, getCardModelType(), "Raise +2 Stone Prod. ",
                            new ChangeAttributeCommand("StoneProduction", 2, ChangeAttributeCommand.CURRENT));
                        break;
                    case 3:
                        model = new CardModel("Extra Turet", 8, getCardModelType(), " Build +9 Wall ",
                            new ChangeAttributeCommand("Wall", 9, ChangeAttributeCommand.CURRENT));
                        break;
                    case 4:
                        model = new CardModel("Fog Shield", 5, getCardModelType(), " Build +7 Wall ",
                            new ChangeAttributeCommand("Wall", 7, ChangeAttributeCommand.CURRENT));
                        break;
                    case 5:
                        model = new CardModel("Town Watch", 6, getCardModelType(), " Build +8 Tower ",
                            new ChangeAttributeCommand("Tower", 8, ChangeAttributeCommand.CURRENT));
                        break;
                    case 6:
                        model = new CardModel("Treasure Hunt", 0, getCardModelType(), " Acquire +10 Gems ",
                            new ChangeAttributeCommand("Gems", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 7:
                        model = new CardModel("Lightning", 0, getCardModelType(), " Attack +12 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -12, ChangeAttributeCommand.OTHER));
                        break;
                    case 8:
                        model = new CardModel("Dragon City", 2, getCardModelType(), " Raise +2 Monst. Prod.",
                            new ChangeAttributeCommand("MonsterProduction", 2, ChangeAttributeCommand.CURRENT));
                        break;
                    case 9:
                        model = new CardModel("Helmet", 2, getCardModelType(), " Build +4 Wall ",
                            new ChangeAttributeCommand("Wall", 4, ChangeAttributeCommand.CURRENT));
                        break;
                }
                break;
            case 1:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Castle Works", 2, getCardModelType(), " Build +5 Wall ",
                            new ChangeAttributeCommand("Wall", 5, ChangeAttributeCommand.CURRENT));
                        break;
                    case 1:
                        model = new CardModel("Chapel", 1, getCardModelType(), " Build +4 Tower ",
                            new ChangeAttributeCommand("Tower", 4, ChangeAttributeCommand.CURRENT));
                        break;
                    case 2:
                        model = new CardModel("LightBeam", 1, getCardModelType(), " Raise +1 Gem Prod.",
                            new ChangeAttributeCommand("GemProduction", 1, ChangeAttributeCommand.CURRENT));
                        break;
                    case 3:
                        model = new CardModel("StoneGates", 12, getCardModelType(), " Build +15 Wall ",
                            new ChangeAttributeCommand("Wall", 15, ChangeAttributeCommand.CURRENT));
                        break;
                    case 4:
                        model = new CardModel("Foundation", 15, getCardModelType(), " Build +20 Wall ",
                            new ChangeAttributeCommand("Wall", 20, ChangeAttributeCommand.CURRENT));
                        break;
                    case 5:
                        model = new CardModel("Stone Bringer", 5, getCardModelType(), " Acquire +15 Stones ",
                            new ChangeAttributeCommand("Stones", 15, ChangeAttributeCommand.CURRENT));
                        break;
                    case 6:
                        model = new CardModel("Fire Shield", 7, getCardModelType(), " Build +7 Wall ",
                            new ChangeAttributeCommand("Wall", 7, ChangeAttributeCommand.CURRENT));
                        break;
                    case 7:
                        model = new CardModel("Alley", 4, getCardModelType(), " Build +5 Tower ",
                            new ChangeAttributeCommand("Tower", 5, ChangeAttributeCommand.CURRENT));
                        break;
                    case 8:
                        model = new CardModel("Magic Mural", 10, getCardModelType(), " Build +10 Tower ",
                            new ChangeAttributeCommand("Tower", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 9:
                        model = new CardModel("Swordman", 4, getCardModelType(), " Attack +5 Wall ",
                            new ChangeAttributeCommand("Wall", -5, ChangeAttributeCommand.OTHER));
                        break;
                }
                break;
            case 2:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Castle Works", 4, getCardModelType(), " Build +10 Wall ",
                            new ChangeAttributeCommand("Wall", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 1:
                        model = new CardModel("Gem Aurora", 0, getCardModelType(), " Raise +1 Monst. Prod.",
                            new ChangeAttributeCommand("MonsterProduction", 1, ChangeAttributeCommand.CURRENT));
                        break;
                    case 2:
                        model = new CardModel("Gem Generator", 6, getCardModelType(), " Raise +2 Gem Prod.",
                            new ChangeAttributeCommand("GemProduction", 2, ChangeAttributeCommand.CURRENT));
                        break;
                    case 3:
                        model = new CardModel("Amazon", 4, getCardModelType(), " Build +5 Wall ",
                            new ChangeAttributeCommand("Wall", 5, ChangeAttributeCommand.CURRENT));
                        break;
                    case 4:
                        model = new CardModel("Castle Works", 4, getCardModelType(), " Build +10 Wall ",
                            new ChangeAttributeCommand("Wall", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 5:
                        model = new CardModel("Armory", 8, getCardModelType(), " Build +4 Wall ",
                            new ChangeAttributeCommand("Wall", 4, ChangeAttributeCommand.CURRENT));
                        break;
                    case 6:
                        model = new CardModel("Cave Beast", 2, getCardModelType(), " Acquire +10 Stones",
                            new ChangeAttributeCommand("Stones", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 7:
                        model = new CardModel("Town Center", 5, getCardModelType(), " Build +6 Tower ",
                            new ChangeAttributeCommand("Tower", 6, ChangeAttributeCommand.CURRENT));
                        break;
                    case 8:
                        model = new CardModel("Full Moon", 0, getCardModelType(), " Raise +1 Gem Prod.",
                            new ChangeAttributeCommand("GemProduction", 1, ChangeAttributeCommand.CURRENT));
                        break;
                    case 9:
                        model = new CardModel("Snow Dragon", 20, getCardModelType(), " Build +11 Tower",
                            new ChangeAttributeCommand("Tower", 11, ChangeAttributeCommand.CURRENT));
                        break;
                }
                break;
            case 3:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Elven Warrior", 0, getCardModelType(), " Kill +10 Enemy Monst. ",
                            new ChangeAttributeCommand("Monsters", -10, ChangeAttributeCommand.OTHER));
                        break;
                    case 1:
                        model = new CardModel("Zombies", 4, getCardModelType(), " Kill +4 Enemy Monst. ",
                            new ChangeAttributeCommand("Monsters", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 2:
                        model = new CardModel("Enlightment", 5, getCardModelType(), " Build +8 Tower",
                            new ChangeAttributeCommand("Tower", 8, ChangeAttributeCommand.CURRENT));
                        break;
                    case 3:
                        model = new CardModel("Architecture", 20, getCardModelType(), " Build +20 Tower",
                            new ChangeAttributeCommand("Tower", 20, ChangeAttributeCommand.CURRENT));
                        break;
                    case 4:
                        model = new CardModel("Red Sphere", 10, getCardModelType(), " Destroy +2 Gem Prod. ",
                            new ChangeAttributeCommand("GemProduction", -2, ChangeAttributeCommand.OTHER));
                        break;
                    case 5:
                        model = new CardModel("Mayhem", 12, getCardModelType(), " Attack +14 Enemy Tower",
                            new ChangeAttributeCommand("Tower", -14, ChangeAttributeCommand.OTHER));
                        break;
                    case 6:
                        model = new CardModel("Cursed Gate", 0, getCardModelType(), " Destroy +2 Stone Prod ",
                            new ChangeAttributeCommand("StoneProduction", -2, ChangeAttributeCommand.OTHER));
                        break;
                    case 7:
                        model = new CardModel("Oak Tree", 3, getCardModelType(), " Raise +1 Gem Prod. ",
                            new ChangeAttributeCommand("GemProduction", 1, ChangeAttributeCommand.CURRENT));
                        break;
                    case 8:
                        model = new CardModel("DragonSlayer", 8, getCardModelType(), " Destroy +3 Monst. Prod. ",
                            new ChangeAttributeCommand("MonsterProduction", -3, ChangeAttributeCommand.OTHER));
                        break;
                    case 9:
                        model = new CardModel("Wizard Library", 40, getCardModelType(), " Build +30 Tower ",
                            new ChangeAttributeCommand("Tower", 30, ChangeAttributeCommand.CURRENT));
                        break;
                }
                break;
        }
        return model;
    }
}
