package com.azt.itower.deck;

import java.awt.Point;
import com.azt.itower.game.GameException;
import com.azt.itower.game.CardModel;
import com.azt.itower.command.*;

/**
 *
 * A Factory Class that adheres to the AbstractDeckFactory rules and provides
 * all the cards of the green deck
 * @author thanassis@thanassis.com
 * @version 0.9 beta */
public class GreenDeckFactory extends AbstractDeckFactory {

    /**
     * Inititalises the GreenDeckFactory
     * @exception GameException
     */
    public void init() throws GameException {
        init(kGREEN_DECK_IMG, CardModel.kMONSTERS);
    }

   /**
     * Creates a model for a card belonging to particular point (row, column)
     * of that deck. The massive switch statement is responsible for creating
     * each card of the green deck.
     * @param Point The point that defines the column and row of the card
     * @return CardModel The CardModel that every Card needs to get state and behaviour
     */
    protected CardModel createCardModel(Point p) {
        CardModel model = null;
        switch (p.y) {
            case 0:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Black Dragon", 12, getCardModelType(), " Attack +12 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -12, ChangeAttributeCommand.OTHER));
                        break;
                    case 1:
                        model = new CardModel("Mars Shield", 3, getCardModelType(), " Build +6 Wall ",
                            new ChangeAttributeCommand("Wall", 6, ChangeAttributeCommand.CURRENT));
                        break;
                        //case 2 : model = new CardModel("Rust Dragon",  0 , getCardModelType(), " +12 monsters",new
                        // ChangeAttributeCommand("Monsters",12,ChangeAttributeCommand.CURRENT));
                    case 2:
                        model = new CardModel("Rust Dragon", 15, getCardModelType(), " Attack +12 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -12, ChangeAttributeCommand.OTHER));
                        break;
                    case 3:
                        model = new CardModel("Broken Siege", 6, getCardModelType(), " Attack +9 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -9, ChangeAttributeCommand.OTHER));
                        break;
                    case 4:
                        model = new CardModel("Serenity", 7, getCardModelType(), " Build +10 Wall ",
                            new ChangeAttributeCommand("Wall", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 5:
                        model = new CardModel("Red Dragon", 18, getCardModelType(), " Attack +12 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -12, ChangeAttributeCommand.OTHER));
                        break;
                    case 6:
                        model = new CardModel("White Rider", 7, getCardModelType(), " Attack +9 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -9, ChangeAttributeCommand.OTHER));
                        break;
                    case 7:
                        model = new CardModel("Angry Dwarf", 3, getCardModelType(), " Attack +4 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 8:
                        model = new CardModel("Azure Dragon", 11, getCardModelType(), " Atack +12 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -12, ChangeAttributeCommand.OTHER));
                        break;
                    case 9:
                        model = new CardModel("WolfMan", 5, getCardModelType(), " Attack +6 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -6, ChangeAttributeCommand.OTHER));
                        break;
                }
                break;
            case 1:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Hypnotize", 6, getCardModelType(), " Build +6 Wall ",
                            new ChangeAttributeCommand("Wall", 6, ChangeAttributeCommand.CURRENT));
                        break;
                    case 1:
                        model = new CardModel("Protection", 10, getCardModelType(), " Build +10 Wall ",
                            new ChangeAttributeCommand("Wall", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 2:
                        model = new CardModel("White Wyvern", 3, getCardModelType(), " Attack +2 Enemy Wall",
                            new ChangeAttributeCommand("Wall", -2, ChangeAttributeCommand.OTHER));
                        break;
                    case 3:
                        model = new CardModel("Fire Flood", 5, getCardModelType(), " Attack +4 Wall ",
                            new ChangeAttributeCommand("Wall", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 4:
                        model = new CardModel("Magic Growth", 0, getCardModelType(), " Acquire +20 Monsters",
                            new ChangeAttributeCommand("Monsters", 20, ChangeAttributeCommand.CURRENT));
                        break;
                    case 5:
                        model = new CardModel("Invoke Flesh", 11, getCardModelType(), " Attack +11 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -11, ChangeAttributeCommand.OTHER));
                        break;
                    case 6:
                        model = new CardModel("Green Dragon", 20, getCardModelType(), " Attack +15 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -15, ChangeAttributeCommand.OTHER));
                        break;
                    case 7:
                        model = new CardModel("Slavery", 8, getCardModelType(), " Build +5 Wall ",
                            new ChangeAttributeCommand("Wall", 5, ChangeAttributeCommand.CURRENT));
                        break;
                    case 8:
                        model = new CardModel("Blue Phoenix", 10, getCardModelType(), " Attack +9 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -9, ChangeAttributeCommand.OTHER));
                        break;
                    case 9:
                        model = new CardModel("Skeleton", 2, getCardModelType(), " Attack +3 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -3, ChangeAttributeCommand.OTHER));
                        break;
                }
                break;
            case 2:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Gem Mines", 5, getCardModelType(), " Raise +2 Gem Prod. ",
                            new ChangeAttributeCommand("GemProduction", 2, ChangeAttributeCommand.CURRENT));
                        break;
                    case 1:
                        model = new CardModel("Dragon Eater", 10, getCardModelType(), " Destroy +10 Enemy Monst.",
                            new ChangeAttributeCommand("Monsters", -10, ChangeAttributeCommand.OTHER));
                        break;
                    case 2:
                        model = new CardModel("Wall Guard", 5, getCardModelType(), " Build +5 Wall",
                            new ChangeAttributeCommand("Wall", 5, ChangeAttributeCommand.CURRENT));
                        break;
                    case 3:
                        model = new CardModel("Knight Guard", 10, getCardModelType(), " Build +15 Wall",
                            new ChangeAttributeCommand("Wall", 15, ChangeAttributeCommand.CURRENT));
                        break;
                    case 4:
                        model = new CardModel("Minotaur", 3, getCardModelType(), " Attack +4 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 5:
                        model = new CardModel("Crusader", 4, getCardModelType(), " Attack +8 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -8, ChangeAttributeCommand.OTHER));
                        break;
                    case 6:
                        model = new CardModel("Death Plague", 0, getCardModelType(), " Destroy +15 Enemy Monst.",
                            new ChangeAttributeCommand("Monsters", -15, ChangeAttributeCommand.OTHER));
                        break;
                    case 7:
                        model = new CardModel("Death Caster", 15, getCardModelType(), " Attack +10 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -10, ChangeAttributeCommand.OTHER));
                        break;
                    case 8:
                        model = new CardModel("Siege", 5, getCardModelType(), " Attack +5 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -5, ChangeAttributeCommand.OTHER));
                        break;
                    case 9:
                        model = new CardModel("Horned Dragon", 20, getCardModelType(), " Attack +20 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -20, ChangeAttributeCommand.OTHER));
                        break;
                }
                break;
            case 3:
                switch (p.x) {
                    case 0:
                        model = new CardModel("Pathfinding", 2, getCardModelType(), " Acquire +10 Stones",
                            new ChangeAttributeCommand("Stones", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 1:
                        model = new CardModel("Typhoon", 2, getCardModelType(), " Destroy +7 Enemy Gems ",
                            new ChangeAttributeCommand("Gems", -7, ChangeAttributeCommand.OTHER));
                        break;
                    case 2:
                        model = new CardModel("Air Spy", 3, getCardModelType(), " Destroy +3 Enemy Monst. ",
                            new ChangeAttributeCommand("Monster", -3, ChangeAttributeCommand.OTHER));
                        break;
                    case 3:
                        model = new CardModel("Mosquito", 6, getCardModelType(), " Attack +4 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 4:
                        model = new CardModel("Evil Octapus", 10, getCardModelType(), " Attack +11 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -11, ChangeAttributeCommand.OTHER));
                        break;
                    case 5:
                        model = new CardModel("Twin Fighters", 2, getCardModelType(), " Attack +4 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 6:
                        model = new CardModel("Bugs", 0, getCardModelType(), " Attack +4 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -4, ChangeAttributeCommand.OTHER));
                        break;
                    case 7:
                        model = new CardModel("Magic Portal", 0, getCardModelType(), " Acquire +10 Gems",
                            new ChangeAttributeCommand("Gems", 10, ChangeAttributeCommand.CURRENT));
                        break;
                    case 8:
                        model = new CardModel("Red Curse", 22, getCardModelType(), " Attack +17 Enemy Wall ",
                            new ChangeAttributeCommand("Wall", -17, ChangeAttributeCommand.OTHER));
                        break;
                    case 9:
                        model = new CardModel("Mephisto", 12, getCardModelType(), " Attack +11 Enemy Tower ",
                            new ChangeAttributeCommand("Tower", -11, ChangeAttributeCommand.OTHER));
                        break;
                }
                break;
        }
        return model;
    }
}
