package com.azt.itower.game;

import com.azt.itower.command.Command;
/**
 *
 * Objects of this type represent models of cards with state and behaviour
 * @author thanassis@thanassis.com
 * @version 0.9 beta
 */
public class CardModel {
    public static final int kMONSTERS = 0;
    public static final int kGEMS = 1;
    public static final int kSTONES = 2;
    private String name;
    private String actionTitle;
    private Command command;
    private int cost;
    private int modelType;

    /**
     * To create a model we need a name, cost in a particular resource type
     * the resource type and finally a command object that provides the
     * executing behaviour
     * @param String the Name of the Card
     * @param int The Type of Resource that the Card Represents
     * @param String The title of the Card
     * @param COmmand The commans that the Card needs to execute when played
     */
    public CardModel(String name, int cost, int modelType, String actionTitle, Command command) {
        this.name = name;
        this.cost = cost;
        this.modelType = modelType;
        this.actionTitle = actionTitle;
        this.command = command;
    }

    /**
     * returns the name of a card
     * @return String
     */
    public String getName() {
        return name;
    }

    /**
     * returns the cost of a card
     */
    public int getCost() {
        return cost;
    }

    /**
     * returns the action title of a card
     * @return String
     */
    public String getActionTitle() {
        return actionTitle;
    }

    /**
     * returns the command that is needed for the execution
     * @return Command
     */
   public Command getCommand() {
        return command;
    }

    /**
     * returns the modeltype of a card
     */
    public final int getModelType() {
        return modelType;
    }


    public void execute() {
        command.execute();
        Player player = IvoryTower.currentPlayer;
        if (getModelType() == kMONSTERS) {
            player.setMonsters(player.getMonsters() - getCost());
        } else if (getModelType() == kGEMS) {
            player.setGems(player.getGems() - getCost());
        } else if (getModelType() == kSTONES) {
            player.setStones(player.getStones() - getCost());
        }
    }

    /**
     * executes the card
     * @return boolean
     */
    public boolean canExecute() {
        if (getModelType() == kSTONES) {
            if (IvoryTower.currentPlayer.getStones() >= getCost())
                return true;
        } else if (getModelType() == kGEMS) {
            if (IvoryTower.currentPlayer.getGems() >= getCost())
                return true;
        } else if (getModelType() == kMONSTERS) {
            if (IvoryTower.currentPlayer.getMonsters() >= getCost())
                return true;
        }
        return false;
    }
}
