package com.azt.itower.game;

import java.awt.*;
import java.awt.event.*;
import com.azt.itower.util.*;

/**
 *
 * DeckPanel represents the panel where the interaction with the
 * human player happens. It views the hand of the player and allows hit detection
 * @author thanassis@thanassis.com
 * @version 0.9 beta
 */
public class DeckPanel extends Panel implements DeckChangeListener, ResourceConstants, KeyListener {
    private Player fPlayer;
    private int lastSelectedCard;
    private Image imageBuf;
    private boolean debug = false;

    /**
     * A deck Panel needs a player to ba constructed
     * @param Player The Owner of the DeckPanel
     */
    DeckPanel(Player p) {
        lastSelectedCard = -1;
        fPlayer = p;
        setBackground(new Color(0, 16, 8));
        addMouseListener(
            new MouseAdapter() {
                public void mousePressed(MouseEvent me) {
                    //selectCoordinates(me.getX(), me.getY());
                    selectCard(me.getX(), me.getY(), true);
                }
                public void mouseReleased(MouseEvent e) {
                    mapMouseCoordinates(e.getX(), e.getY());
                }
            });
        addMouseMotionListener(
            new MouseMotionAdapter() {
                public void mouseDragged(MouseEvent me) {
                    selectCard(me.getX(), me.getY(), false);
                }
            });
        addKeyListener(this);
    }

        /**
     * Empty implementation to satisfy the KeyListener interface
     * @param KeyEvent
     * @see java.awt.event.KeyEvent
     */
    public void keyTyped(KeyEvent e) {
    }

    /**
     * Empty implementation to satisfy the KeyListener interface
     * @param KeyEvent
     * @see java.awt.event.KeyEvent
     */
    public void keyPressed(KeyEvent e) {
    }

    /**
     * Handles the KeyEvents on the release of a key
     * @param KeyEvent
     * @see java.awt.event.KeyEvent
     */
    private StringBuffer cheatString = new StringBuffer();
    public void keyReleased(KeyEvent e) {
        char c = e.getKeyChar();
        if (c=='\n') cheatString = new StringBuffer();
        cheatString.append(c);
        checkForCompletion();
        if (cheatString.length()>100) {
           cheatString = new StringBuffer();
        }
    }

    private void checkForCompletion(){
       if (cheatString.toString().indexOf("cheatON")>-1) {
          debug=true;
          cheatString = new StringBuffer();
          repaint();

       } else if (cheatString.toString().indexOf("cheatOFF")>0) {
          debug=false;
          cheatString = new StringBuffer();
          repaint();
       }

    }


    /**
     * Sets the Player
     * @param Player The Owner of the DeckPanel
     */
    public void setPlayer(Player p) {
        fPlayer = p;
    }

    /**
     * Detects Selection and highlights the card accordingly
     * @param int the X coordinate
     * @param int the y coordinate
     * @param boolean With Sound or not
     */
    private void selectCard(int x, int y, boolean playSound) {
      if (interaction) {
        Hand thehand = fPlayer.getHand();
        int selectedCard = thehand.getSelectedCard(x, y);
        if ((selectedCard != -1)) {
            SoundRegistry.getInstance().playWavAudio(kPICK_SND);
            if (selectedCard != lastSelectedCard) {
                if (thehand.getCardAt(selectedCard).canExecute())
                    thehand.getCardAt(selectedCard).paintSelection(getGraphics(), Color.green);
                else
                    thehand.getCardAt(selectedCard).paintSelection(getGraphics(), Color.red);
            }
            //GameLogger.log("is hit on: " + x +  "," + y);
        }
        if (lastSelectedCard != -1 && lastSelectedCard != selectedCard) {
            Card tempCard = thehand.getCardAt(lastSelectedCard);
            if (tempCard != null)
                tempCard.paint(getGraphics(), this);
        }
        lastSelectedCard = selectedCard;
      }
    }

    private boolean interaction = false;
    public void acceptInteraction(boolean b) {
       interaction=b;
    }

    /**
     * Handles the events of the Mouse
     * @param int x The X Coordinate
     * @param int y The Y Coordinate
     */
    private void mapMouseCoordinates(int x, int y) {
        if (debug) {
          if ((x>740) && ( x<750) && (y>10) && (y<20)) {
          int ws = IvoryTower.currentPlayer.getWallSize();
          ws++;
          IvoryTower.currentPlayer.setWallSize(ws);

        } else

         if ((x>740) && ( x<750) && (y>20) && (y<30)) {
          int ws = IvoryTower.currentPlayer.getWallSize();
          ws--;
          IvoryTower.currentPlayer.setWallSize(ws);

        } else

        if ((x>750) && ( x<760) && (y>10) && (y<20)) {
          int ws = IvoryTower.currentPlayer.getTowerSize();
          ws++;
          IvoryTower.currentPlayer.setTowerSize(ws);

        } else

         if ((x>750) && ( x<760) && (y>20) && (y<30)) {
          int ws = IvoryTower.currentPlayer.getTowerSize();
          ws--;
          IvoryTower.currentPlayer.setTowerSize(ws);

        } else


          if ((x>760) && ( x<770) && (y>10) && (y<20)) {
          int ws = IvoryTower.otherPlayer.getWallSize();
          ws++;
          IvoryTower.otherPlayer.setWallSize(ws);

        } else

         if ((x>760) && ( x<770) && (y>20) && (y<30)) {
          int ws = IvoryTower.otherPlayer.getWallSize();
          ws--;
          IvoryTower.otherPlayer.setWallSize(ws);

        } else


          if ((x>770) && ( x<780) && (y>10) && (y<20)) {
          int ws = IvoryTower.otherPlayer.getTowerSize();
          ws++;
          IvoryTower.otherPlayer.setTowerSize(ws);

        } else

         if ((x>770) && ( x<780) && (y>20) && (y<30)) {
          int ws = IvoryTower.otherPlayer.getTowerSize();
          ws--;
          IvoryTower.otherPlayer.setTowerSize(ws);

        }


        }

        if (interaction) {
        Card[] arr = fPlayer.getHand().getCards();
        for (int i = 0; i < arr.length; i++) {
            if (arr[i] != null)
                if (arr[i].isHit(x, y)) {
                    SoundRegistry.getInstance().playWavAudio(kRELEASE_SND);
                    if (arr[i].canExecute()) {
                        arr[i].execute();
                        //GameLogger.log("Player has executed" + arr[i].getName() + arr[i].getModel().getActionTitle());
                    } else {
                        // discard card from the deck
                        //GameLogger.log("Player has discarded" + arr[i].getName() + arr[i].getModel().getActionTitle());
                    }
                    DeckManager.getInstance().pushCard(arr[i]);
                    arr[i] = null;
                    fPlayer.hasPlayed();
                }
        } //end for
        lastSelectedCard = -1;
        }
    }

    /**
     * Paints all the cards of the owner Player's hand
     * @param Graphics AWT's Graphics Context
     * @see java.awt.Graphics
     */
    public void paint(Graphics g) {
        imageBuf = createImage(780, 140);
        Graphics Grbuffer = imageBuf.getGraphics();
        Card[] cardArr = fPlayer.getHand().getCards();
        //azt bug
        if (fPlayer.getHand().isFull()) {
            for (int i = 0; i < cardArr.length; i++) {
                cardArr[i].setOrigin(
                    new Point(42 + 120 * i, 0));
                cardArr[i].paint(Grbuffer, this);
            }
        }
        g.drawImage(imageBuf, 0, 0, this);
      if (debug) {
       g.setColor(new Color(150,150,250));
       g.fillOval(740,10,10,10);
       g.setColor(new Color(120,120,200));
       g.fillOval(740,20,10,10);

       g.setColor(new Color(150,150,255));
       g.fillOval(750,10,10,10);
       g.setColor(new Color(120,120,190));
       g.fillOval(750,20,10,10);

       g.setColor(new Color(220,150,150));
       g.fillOval(760,10,10,10);
       g.setColor(new Color(200,120,120));
       g.fillOval(760,20,10,10);

       g.setColor(new Color(230,150,150));
       g.fillOval(770,10,10,10);
       g.setColor(new Color(210,120,120));
       g.fillOval(770,20,10,10);
      }
    }

    /**
     * Returns the preferred size
     * @return Dimension
     */
    public Dimension getPreferredSize() {
        return new Dimension(780, 130);
    }

    /**
     * Handles deckChanged announcements
     */
    public void deckChanged() {
        repaint();
    }

    /**
     * upate overides the awt method to give explicit size
     * @param Graphics AWT's Graphics Context
     * @see java.awt.Graphics
     * @see java.awt.Component.update(Graphics g)
     */
    public void update(Graphics g) {
        paint(g);
    }
}
