package com.azt.itower.game;

import com.azt.itower.util.*;

/**
 *
 * A Hand is the collection of cards that each player has at its hand
 * @author thanassis@thanassis.com
 * @version 0.9 beta
 */
public class Hand {
    private static final int kMAX_SIZE = 6;
    private Card[] fCard;

    /**
     * Constructor for a Hand object
     */
    public Hand() {
        fCard = new Card[kMAX_SIZE];
    }

    /**
     * Refreshes the hand by replacing all the missing cards
     * using the DeckManager
     */
    public void refresh() {
        DeckManager dm = DeckManager.getInstance();
        for (int i = 0; i < fCard.length; i++)
            if (fCard[i] == null)
                fCard[i] = dm.popCard();
    }

    public void resetHand() {
        DeckManager dm = DeckManager.getInstance();
        for (int i = 0; i < fCard.length; i++)
            if (fCard[i] != null) {
                dm.pushCard(fCard[i]);
                fCard[i] = null;
            }
    }



    /**
     * Queries to find if the hand is full
     * @return boolean Finds out if the hand is full
     */
    public boolean isFull() {
        for (int i = 0; i < fCard.length; i++)
            if (fCard[i] == null)
                return false;
        return true;
    }

    /**
     * Gets the card at index position
     * @param int the index
     * @return Card The card at index position
     */
    public Card getCardAt(int index) {
        if (index > -1 && index < kMAX_SIZE)
            return fCard[index];
        return null;
    }

    /**
     * Clears the card at index position
     * @param int the index
     */
    public void clearCardAt(int index) {
        if (index > -1 && index < kMAX_SIZE)
            fCard[index] = null;
    }

    /**
     * Removes the provided card from the hand
     * @param Card
     */
    public void clearCard(Card card) {
        for (int i = 0; i < fCard.length; i++) {
            Card tCard = fCard[i];
            if (tCard == card)
                clearCardAt(i);
        }
    }

    /**
     * Returns the position of the SelectedCard
     * @param int The X coordinate
     * @param int The Y coordinate
     * @return int the index of the Card in this hand
     */
    public int getSelectedCard(int x, int y) {
        for (int i = 0; i < fCard.length; i++)
            if (fCard[i] != null && fCard[i].isHit(x, y))
                return i;
        return -1;
    }

    /**
     * Returns the number of cards that the hand contains
     * @return int The length of the hand
     */
    public int getLength() {
        return fCard.length;
    }


    /**
     * Returns the cards in an array of Cards
     * @return Card[] An array with all the Cards of this hand
     */
    public Card[] getCards() {
        return fCard;
    }
}
