package com.azt.itower.util;

import java.io.*;

/**
 * Logs messages
 * @author thanassis@thanassis.com
 * @version 0.9 beta
 */
class Logger {
    private static final String kEMPTY_STRING = "";
    private PrintWriter writer;
    private String header;
    private boolean outputHeader;

    /**
     * Constructs a logger
     * @param OutputStream The stream where the logging gets print
     * @param String The header of the logging message
     * @param boolean Indication to switch the printing of the header
     */
    public Logger(OutputStream stream, String headermsg, boolean outputTheHeader) {
        writer = new PrintWriter(stream);
        header = headermsg;
        outputHeader = outputTheHeader;
    }


    /**
     * Constructs a logger
     * @param OutputStream The stream where the logging gets print
     * @param String The header of the logging message
     */
    public Logger(OutputStream stream, String headermsg) {
        this(stream, headermsg, false);
    }

    /**
     * Logs a message
     * @param String The message thta need logging
     */
    public void log(String msg) {
        writer.print(getHeader());
        writer.println(msg);
        writer.flush();
    }

    /**
     * Logs a message and  a throwable (exception or error)
     * @param String The logging message
     * @param Throwable An exception to be attached
     */
    public void log(String msg, Throwable t) {
        writer.print(getHeader());
        writer.println(msg);
        t.printStackTrace(writer);
        writer.flush();
    }

    /**
     * Logs a throwable (exception or error)
     * @param Throwable An exception to be attached
     */
    public void log(Throwable t) {
        writer.print(getHeader());
        t.printStackTrace(writer);
        writer.flush();
    }

    /**
     * Returns the header of the logger
     * @return String The header
     */
    private String getHeader() {
        if (outputHeader) {
            StringBuffer buf = new StringBuffer("[");
            buf.append(header);
            buf.append(":");
            //buf.append(java.util.Calendar.getInstance().getTime().toString());
            buf.append("] ");
            return buf.toString();
        }
        return kEMPTY_STRING;
    }
}
